Crate userspace_pagefault

Crate userspace_pagefault 

Re-exports

pub use nix::libc;

Structs

PagedSegment
Memory segment that allows customized page fault handling in user space.
ProtFlags
Desired memory protection of a memory mapping.
Segment
A segment of OS memory.
SharedMemory
Reference used to share memory among Segment (or PagedSegment).
VecPageStore

Enums

AccessType
Error

Traits

PageStore
Backend store for the user-space paging. The store is a collection of pages for their persistent contents.

Functions

get_page_size
Obtain the page size of the current platform.