pub struct SharedMemory(/* private fields */);Expand description
Reference used to share memory among Segment (or PagedSegment).
For the reference created by SharedMemory::new, the patched portion of Segment or PagedSegment will be mapped to share the same memory content. Cloning SharedMemory only duplicates the reference, not the underlying memory.
Implementations